@@ -64,63 +64,64 @@ long fs_GetFullPath(char *pathp, char *outPathp, long outSize)
 {
 	char tpath[1000];
 	char origPath[1000];
-        char *firstp;
-        long code;
-        int pathHasDrive;
-        int doSwitch;
-        char newPath[3];
+    char *firstp;
+    long code;
+    int pathHasDrive;
+    int doSwitch;
+    char newPath[3];
 
 	if (pathp[0] != 0 && pathp[1] == ':') {
 		/* there's a drive letter there */
-                firstp = pathp+2;
-                pathHasDrive = 1;
-        }
-        else {
-	        firstp = pathp;
+        firstp = pathp+2;
+        pathHasDrive = 1;
+    }
+    else {
+        firstp = pathp;
 		pathHasDrive = 0;
-	}
+	}   
         
-        if (*firstp == '\\' || *firstp == '/') {
+    if (*firstp == '\\' || *firstp == '/') {
 		/* already an absolute pathname, just copy it back */
-                strcpy(outPathp, firstp);
-                return 0;
-        }
+        strcpy(outPathp, firstp);
+        return 0;
+    }
         
-        GetCurrentDirectory(sizeof(origPath), origPath);
+    GetCurrentDirectory(sizeof(origPath), origPath);
         
 	doSwitch = 0;
-        if (pathHasDrive && (*pathp & ~0x20) != (origPath[0] & ~0x20)) {
+    if (pathHasDrive && (*pathp & ~0x20) != (origPath[0] & ~0x20)) {
 		/* a drive has been specified and it isn't our current drive.
-                 * to get path, switch to it first.  Must case-fold drive letters
-                 * for user convenience.
-                 */
+         * to get path, switch to it first.  Must case-fold drive letters
+         * for user convenience.
+         */
 		doSwitch = 1;
-                newPath[0] = *pathp;
-                newPath[1] = ':';
-                newPath[2] = 0;
-                if (!SetCurrentDirectory(newPath)) {
+        newPath[0] = *pathp;
+        newPath[1] = ':';
+        newPath[2] = 0;
+        if (!SetCurrentDirectory(newPath)) {
 			code = GetLastError();
-                        return code;
-                }
+            return code;
         }
+    }
         
-        /* now get the absolute path to the current wdir in this drive */
-        GetCurrentDirectory(sizeof(tpath), tpath);
-        strcpy(outPathp, tpath+2);	/* skip drive letter */
+    /* now get the absolute path to the current wdir in this drive */
+    GetCurrentDirectory(sizeof(tpath), tpath);
+    strcpy(outPathp, tpath+2);	/* skip drive letter */
 	/* if there is a non-null name after the drive, append it */
 	if (*firstp != 0) {
-	        strcat(outPathp, "\\");
-	        strcat(outPathp, firstp);
+        strcat(outPathp, "\\");
+        strcat(outPathp, firstp);
 	}
 
 	/* finally, if necessary, switch back to our home drive letter */
-        if (doSwitch) {
+    if (doSwitch) {
 		SetCurrentDirectory(origPath);
-        }
+    }
         
-        return 0;
+    return 0;
 }
 
+#ifdef COMMENT
 struct hostent *hostutil_GetHostByName(char *namep)
 {
 	struct hostent *thp;
@@ -149,6 +150,7 @@ char *hostutil_GetNameByINet(afs_uint32 addr)
 	/* return static buffer */
         return hostNameBuffer;
 }
+#endif
 
 /* is this a digit or a digit-like thing? */
 static int ismeta(ac, abase)
