@@ -22,7 +22,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vnodeops.c,v 1.81.2.5 2004/12/07 06:12:13 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vnodeops.c,v 1.81.2.11 2005/01/31 04:23:11 shadow Exp $");
 
 #include "afs/sysincludes.h"
 #include "afsincludes.h"
@@ -518,6 +518,9 @@ afs_linux_mmap(struct file *fp, struct vm_area_struct *vmap)
     if (!code)
 	code = afs_VerifyVCache(vcp, &treq);
 
+    if (!code && (vcp->states & CRO) && 
+	(vmap->vm_file->f_flags & (FWRITE | FTRUNC)))
+	code = EACCES;
 
     if (code)
 	code = -code;
@@ -756,6 +759,9 @@ struct file_operations afs_file_fops = {
   .mmap =	afs_linux_mmap,
   .open =	afs_linux_open,
   .flush =	afs_linux_flush,
+#ifdef AFS_LINUX26_ENV
+  .sendfile =   generic_file_sendfile,
+#endif
   .release =	afs_linux_release,
   .fsync =	afs_linux_fsync,
   .lock =	afs_linux_lock,
@@ -1044,7 +1050,6 @@ afs_linux_create(struct inode *dip, struct dentry *dp, int mode)
 #endif
 
 	dp->d_op = &afs_dentry_operations;
-	dp->d_time = jiffies;
 	d_instantiate(dp, ip);
     }
 
@@ -1115,7 +1120,6 @@ afs_linux_lookup(struct inode *dip, struct dentry *dp)
 	    ip->i_op = &afs_symlink_iops;
 #endif
     }
-    dp->d_time = jiffies;
     dp->d_op = &afs_dentry_operations;
     d_add(dp, AFSTOI(vcp));
 
@@ -1163,18 +1167,63 @@ afs_linux_link(struct dentry *olddp, struct inode *dip, struct dentry *newdp)
 int
 afs_linux_unlink(struct inode *dip, struct dentry *dp)
 {
-    int code;
+    int code = EBUSY;
     cred_t *credp = crref();
     const char *name = dp->d_name.name;
+    struct vcache *tvc = ITOAFS(dp->d_inode);
 
 #if defined(AFS_LINUX26_ENV)
     lock_kernel();
 #endif
+    if (((VREFCOUNT(tvc) > 0) && tvc->opens > 0)
+				&& !(tvc->states & CUnlinked)) {
+	struct dentry *__dp;
+	char *__name;
+	extern char *afs_newname();
+
+	__dp = NULL;
+	__name = NULL;
+	do {
+	    dput(__dp);
+
+	    AFS_GLOCK();
+	    if (__name)
+		osi_FreeSmallSpace(__name);
+	    __name = afs_newname();
+	    AFS_GUNLOCK();
+
+	    __dp = lookup_one_len(__name, dp->d_parent, strlen(__name));
+		
+	    if (IS_ERR(__dp))
+		goto out;
+	} while (__dp->d_inode != NULL);
+
+	AFS_GLOCK();
+	code = afs_rename(ITOAFS(dip), dp->d_name.name, ITOAFS(dip), __dp->d_name.name, credp);
+	if (!code) {
+            tvc->mvid = __name;
+            crhold(credp);
+            if (tvc->uncred) {
+                crfree(tvc->uncred);
+            }
+            tvc->uncred = credp;
+	    tvc->states |= CUnlinked;
+	}
+	AFS_GUNLOCK();
+
+	if (!code)
+	    d_move(dp, __dp);
+	dput(__dp);
+
+	goto out;
+    }
+
     AFS_GLOCK();
     code = afs_remove(ITOAFS(dip), name, credp);
     AFS_GUNLOCK();
     if (!code)
 	d_drop(dp);
+out:
 #if defined(AFS_LINUX26_ENV)
     unlock_kernel();
 #endif
@@ -1229,7 +1278,6 @@ afs_linux_mkdir(struct inode *dip, struct dentry *dp, int mode)
 	tvcp->v.v_fop = &afs_dir_fops;
 #endif
 	dp->d_op = &afs_dentry_operations;
-	dp->d_time = jiffies;
 	d_instantiate(dp, AFSTOI(tvcp));
     }
 
@@ -1283,8 +1331,10 @@ afs_linux_rename(struct inode *oldip, struct dentry *olddp,
     cred_t *credp = crref();
     const char *oldname = olddp->d_name.name;
     const char *newname = newdp->d_name.name;
+    struct dentry *rehash = NULL;
 
 #if defined(AFS_LINUX26_ENV)
+    /* Prevent any new references during rename operation. */
     lock_kernel();
 #endif
     /* Remove old and new entries from name hash. New one will change below.
@@ -1293,25 +1343,28 @@ afs_linux_rename(struct inode *oldip, struct dentry *olddp,
      * cases. Let another lookup put things right, if need be.
      */
 #if defined(AFS_LINUX26_ENV)
-    if (!d_unhashed(olddp))
-	d_drop(olddp);
-    if (!d_unhashed(newdp))
+    if (!d_unhashed(newdp)) {
 	d_drop(newdp);
+	rehash = newdp;
+    }
 #else
-    if (!list_empty(&olddp->d_hash))
-	d_drop(olddp);
-    if (!list_empty(&newdp->d_hash))
+    if (!list_empty(&newdp->d_hash)) {
 	d_drop(newdp);
+	rehash = newdp;
+    }
 #endif
+
+#if defined(AFS_LINUX24_ENV)
+    if (atomic_read(&olddp->d_count) > 1)
+	shrink_dcache_parent(olddp);
+#endif
+
     AFS_GLOCK();
     code = afs_rename(ITOAFS(oldip), oldname, ITOAFS(newip), newname, credp);
     AFS_GUNLOCK();
 
-    if (!code) {
-	/* update time so it doesn't expire immediately */
-	newdp->d_time = jiffies;
-	d_move(olddp, newdp);
-    }
+    if (rehash)
+	d_rehash(rehash);
 
 #if defined(AFS_LINUX26_ENV)
     unlock_kernel();
@@ -1795,7 +1848,11 @@ struct address_space_operations afs_symlink_aops = {
 struct inode_operations afs_symlink_iops = {
 #if defined(AFS_LINUX24_ENV)
   .readlink = 		page_readlink,
+#if defined(HAVE_KERNEL_PAGE_FOLLOW_LINK)
   .follow_link =	page_follow_link,
+#else
+  .follow_link =	page_follow_link_light,
+#endif
   .setattr =		afs_notify_change,
 #else
   .readlink = 		afs_linux_readlink,
