@@ -46,8 +46,8 @@
 #define SYS_NAME_ID_hp_ux102	 	 414
 #define SYS_NAME_ID_hp_ux110	 	 415
 #define SYS_NAME_ID_hp_ux11i             416
-#define SYS_NAME_ID_ia64_hpux1122		 417
-#define SYS_NAME_ID_ia64_hpux1123		 418
+#define SYS_NAME_ID_ia64_hpux1122	 417
+#define SYS_NAME_ID_ia64_hpux1123	 418
 
 #define SYS_NAME_ID_mac2_51		 500
 #define SYS_NAME_ID_mac_aux10		 501
@@ -92,12 +92,14 @@
 #define SYS_NAME_ID_sun4x_57		 938
 #define SYS_NAME_ID_sun4x_58		 939
 #define SYS_NAME_ID_sun4x_59		 940
+#define SYS_NAME_ID_sun4x_510		 941
 
 /* Sigh. If I leave a gap here IBM will do this sequentially. If I don't
    they won't allocate sunx86 IDs at all. So leave a gap and pray. */
-#define SYS_NAME_ID_sunx86_57            950
-#define SYS_NAME_ID_sunx86_58            951
-#define SYS_NAME_ID_sunx86_59            952
+#define SYS_NAME_ID_sunx86_57		 950
+#define SYS_NAME_ID_sunx86_58		 951
+#define SYS_NAME_ID_sunx86_59		 952
+#define SYS_NAME_ID_sunx86_510		 953
 
 #define SYS_NAME_ID_vax_ul4		1003
 #define SYS_NAME_ID_vax_ul40		1004
@@ -136,6 +138,7 @@
 #define SYS_NAME_ID_ppc_linux2          1600
 #define SYS_NAME_ID_ppc_linux22         1601
 #define SYS_NAME_ID_ppc_linux24         1602
+#define SYS_NAME_ID_ppc_linux26         1603
 
 #define SYS_NAME_ID_sparc_linux2	1700
 #define SYS_NAME_ID_sparc_linux22	1701
@@ -148,6 +151,9 @@
 #define SYS_NAME_ID_s390_linux2         1900
 #define SYS_NAME_ID_s390_linux22        1901
 #define SYS_NAME_ID_s390_linux24        1902
+#define SYS_NAME_ID_s390x_linux2         1903
+#define SYS_NAME_ID_s390x_linux22        1904
+#define SYS_NAME_ID_s390x_linux24        1905
 
 #define SYS_NAME_ID_alpha_linux_2       2000
 #define SYS_NAME_ID_alpha_linux_22      2001
@@ -162,10 +168,12 @@
 #define SYS_NAME_ID_i386_fbsd_50        2105
 #define SYS_NAME_ID_i386_fbsd_51        2106
 #define SYS_NAME_ID_i386_fbsd_52        2107
+#define SYS_NAME_ID_i386_fbsd_53        2108
 
 #define SYS_NAME_ID_ia64_linux2		2200
 #define SYS_NAME_ID_ia64_linux22	2201
 #define SYS_NAME_ID_ia64_linux24	2202
+#define SYS_NAME_ID_ia64_linux26	2203
 
 #define SYS_NAME_ID_m68k_linux22        2301
 #define SYS_NAME_ID_m68k_linux24        2302
@@ -189,24 +197,30 @@
 #define SYS_NAME_ID_sparc_nbsd20	2522
 #define SYS_NAME_ID_sparc64_nbsd20	2523
 #define SYS_NAME_ID_macppc_nbsd20	2524
+#define SYS_NAME_ID_i386_nbsd21		2525
+#define SYS_NAME_ID_i386_nbsd30		2526
 
 #define SYS_NAME_ID_i386_obsd31		2600
 #define SYS_NAME_ID_i386_obsd32		2601
 #define SYS_NAME_ID_i386_obsd33		2602
 #define SYS_NAME_ID_i386_obsd34		2603
 #define SYS_NAME_ID_i386_obsd35		2604
+#define SYS_NAME_ID_i386_obsd36		2605
 
 #define SYS_NAME_ID_amd64_linux2        2700
 #define SYS_NAME_ID_amd64_linux22       2701
 #define SYS_NAME_ID_amd64_linux24       2702
+#define SYS_NAME_ID_amd64_linux26       2703
 
 #define SYS_NAME_ID_i386_umlinux2	2800
 #define SYS_NAME_ID_i386_umlinux22	2801
 #define SYS_NAME_ID_i386_umlinux24	2802
+#define SYS_NAME_ID_i386_umlinux26	2803
 
 #define SYS_NAME_ID_ppc64_linux2	2900
 #define SYS_NAME_ID_ppc64_linux22	2901
 #define SYS_NAME_ID_ppc64_linux24	2902
+#define SYS_NAME_ID_ppc64_linux26	2903
 
 /*
  * Placeholder to keep system-wide standard flags since this file is included by all 
